@@ -52,8 +52,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("clear", &CTextA::clear, py::arg("bRelease") = false)
         .def("collectBlocks", [](CTextA& s, const char* sepBegin, const char* sepEnd, bool all)->vector<string> {  vector<string> res;  s.collectBlocks(res, sepBegin, sepEnd, all); return res; }, "collect blocks", py::arg("sepBegin"), py::arg("sepEnd"), py::arg("all") = true)
         .def("collectLines", [](CTextA& s, const char* sep)->vector<string> {  vector<string> res;  s.collectLines(res, false, sep); return res; }, "fills a list with the collected lines", py::arg("sep") = CTextA::SeparatorsLine)
-        .def("checkBalance", &CTextA::checkBalance, "checks if the blocks defined with the given separators are balanced")
-        .def("convertToHex", &CTextA::convertToHex, "convert string to hex values", py::arg("sep") = CTextA::SPACE)             
+        .def("checkBalance", &CTextA::checkBalance, "checks if the blocks defined with the given separators are balanced")  
         .def("contain", (bool (CTextA::*)(const char* s, bool bCase) const) &CTextA::contain, "returns true if our string contains another string  ", py::arg("str"), py::arg("case") = true)
         .def("contain", [](CTextA& s, const vector<string>& list, bool bCase)->bool { return s.containAny(list, bCase, true); }, "returns true if contains any of the provided strings", py::arg("list"), py::arg("case") = true)
         .def("containAny", (bool (CTextA::*)(const char* s, bool bCase) const) &CTextA::containAny, "returns true if our string contains any of the characters in the list", py::arg("str"), py::arg("case") = true)
@@ -68,6 +67,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("cutEnds", (CTextA& (CTextA::*)(size_t)) &CTextA::cutEnds, "remove count of characters from left and right", py::arg("count"))
         .def("cutLeft", &CTextA::cutLeft, "removes count characters from left", py::arg("count"))
         .def("cutRight", &CTextA::cutRight, "removes count characters from left", py::arg("count"))
+        .def("enclose", [](CTextA& s, const char* c)->CTextA& {return s.enclose(c[0]); }, "enclose with same character", py::arg("c"))
         .def("enclose", (CTextA& (CTextA::*)(const char* begin, const char* end, bool checkEnds)) &CTextA::enclose, "enclose with the provided text separators (if not already ends and begins with them)", py::arg("begin"), py::arg("end"), py::arg("checkEnds") = true)          
         .def("endsWith", [](CTextA& s, const char* str, bool bCase)->bool { return s.endsWith(str, 0, bCase); }, "return true if ends with the provided string", py::arg("str"), py::arg("case") = true)
         .def("endsWithAny", [](CTextA& s, const vector<string>& list, bool bCase)->bool { return s.endsWithAny(list, 0, bCase, true); }, "returns true if ends with any of the strings from the list", py::arg("list"), py::arg("case") = true)
@@ -82,9 +82,10 @@ PYBIND11_MODULE(ctextlib, m)
         .def("fromBinary", &CTextA::fromBinary<char>, "create a binary string from the number")
         .def("fromBinary", &CTextA::fromBinary<int>, "create a binary string from the number")
         .def("fromBinary", &CTextA::fromBinary<long long>, "create a binary string from the number")
-        .def("fromHex", &CTextA::fromHex<char>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
-        .def("fromHex", &CTextA::fromHex<int>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
-        .def("fromHex", &CTextA::fromHex<long long>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
+        .def("fromHex", &CTextA::fromHex, "create a hexadecimal string from the number", py::arg("s"))
+        .def("fromHex", &CTextA::fromHexNumber<char>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
+        .def("fromHex", &CTextA::fromHexNumber<int>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
+        .def("fromHex", &CTextA::fromHexNumber<long long>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
         .def("fromInteger", &CTextA::fromInteger<char>, "convert the decimal nteger to string", py::arg("i"), py::arg("append") = false, py::arg("padd") = 0, py::arg("paddValue") = '0')
         .def("fromInteger", &CTextA::fromInteger<int>, "convert the decimal nteger to string", py::arg("i"), py::arg("append") = false, py::arg("padd") = 0, py::arg("paddValue") = '0')
         .def("fromInteger", &CTextA::fromInteger<long long>, "convert the decimal integer to string", py::arg("i"), py::arg("append") = false, py::arg("padd") = 0, py::arg("paddValue") = '0')
@@ -178,7 +179,8 @@ PYBIND11_MODULE(ctextlib, m)
         .def("sort", &CTextA::sort)
         .def("split",[](CTextA& s, const char* sep = CTextA::Separators)->vector<string> { vector<string> res;  s.split(res, false, sep); return res; }, "fills the STL container with the collected substrings", py::arg("sep") = CTextA::Separators)
         .def("str", (const char* (CTextA::*)(size_t pos) const) &CTextA::str, "return text buffer", py::arg("pos") = 0)
-        .def("toBinaryNumber", &CTextA::toBinaryNumber, "if the string contains a binary number, convert it  ")
+        .def("toBinary", &CTextA::toBinary, "if the string contains a binary number, convert it  ")
+        .def("toHex", &CTextA::toHex, "convert string to hex values separated by the given separator", py::arg("sep") = CTextA::SPACE)
         .def("toHexNumber", &CTextA::toHexNumber, "if the string contains a hex number, convert it , 1E --> 30")
         .def("toDouble", &CTextA::toDouble)
         .def("toInteger", &CTextA::toInteger)     
@@ -199,7 +201,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("writeFile", &CTextA::writeFile<char>, "write string to a text file with the given encoding", py::arg("path"), py::arg("encoding") = 1, py::arg("asHex") = false)
         ;
         
-         py::class_<CTextU> (m, "CTextU")
+    py::class_<CTextU> (m, "CTextU")
         // constructors
         .def(py::init<>())
         .def(py::init<const wchar_t*>())
@@ -229,7 +231,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("collectBlocks", [](CTextU& s, const wchar_t* sepBegin, const wchar_t* sepEnd, bool all)->vector<wstring> {  vector<wstring> res;  s.collectBlocks(res, sepBegin, sepEnd, all); return res; }, "collect blocks", py::arg("sepBegin"), py::arg("sepEnd"), py::arg("all") = true)
         .def("collectLines", [](CTextU& s, const wchar_t* sep)->vector<wstring> {  vector<wstring> res;  s.collectLines(res, false, sep); return res; }, "fills a list with the collected lines", py::arg("sep") = CTextU::SeparatorsLine)
         .def("checkBalance", &CTextU::checkBalance, "checks if the blocks defined with the given separators are balanced")
-        .def("convertToHex", &CTextU::convertToHex, "convert string to hex values", py::arg("sep") = CTextU::SPACE)
+        .def("convertToHex", &CTextU::toHex, "convert string to hex values", py::arg("sep") = CTextU::SPACE)
         .def("contain", (bool (CTextU::*)(const wchar_t* s, bool bCase) const) &CTextU::contain, "returns true if our string contains another string  ", py::arg("str"), py::arg("case") = true)
         .def("contain", [](CTextU& s, const vector<wstring>& list, bool bCase)->bool { return s.containAny(list, bCase, true); }, "returns true if contains any of the provided strings", py::arg("list"), py::arg("case") = true)
         .def("containAny", (bool (CTextU::*)(const wchar_t* s, bool bCase) const) &CTextU::containAny, "returns true if our string contains any of the characters in the list", py::arg("str"), py::arg("case") = true)
@@ -244,6 +246,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("cutEnds", (CTextU& (CTextU::*)(size_t)) &CTextU::cutEnds, "remove count of characters from left and right", py::arg("count"))
         .def("cutLeft", &CTextU::cutLeft, "removes count characters from left", py::arg("count"))
         .def("cutRight", &CTextU::cutRight, "removes count characters from left", py::arg("count"))
+        .def("enclose", [](CTextU& s, const wchar_t* c)->CTextU& {return s.enclose(c[0]); }, "enclose with same character", py::arg("c"))
         .def("enclose", (CTextU& (CTextU::*)(const wchar_t* begin, const wchar_t* end, bool checkEnds)) &CTextU::enclose, "enclose with the provided text separators (if not already ends and begins with them)", py::arg("begin"), py::arg("end"), py::arg("checkEnds") = true)
         .def("endsWith", [](CTextU& s, const wchar_t* str, bool bCase)->bool { return s.endsWith(str, 0, bCase); }, "return true if ends with the provided string", py::arg("str"), py::arg("case") = true)
         .def("endsWithAny", [](CTextU& s, const vector<wstring>& list, bool bCase)->bool { return s.endsWithAny(list, 0, bCase, true); }, "returns true if ends with any of the strings from the list", py::arg("list"), py::arg("case") = true)
@@ -258,9 +261,9 @@ PYBIND11_MODULE(ctextlib, m)
         .def("fromBinary", &CTextU::fromBinary<char>, "create a binary string from the number")
         .def("fromBinary", &CTextU::fromBinary<int>, "create a binary string from the number")
         .def("fromBinary", &CTextU::fromBinary<long long>, "create a binary string from the number")
-        .def("fromHex", &CTextU::fromHex<char>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
-        .def("fromHex", &CTextU::fromHex<int>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
-        .def("fromHex", &CTextU::fromHex<long long>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
+        .def("fromHex", &CTextU::fromHexNumber<char>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
+        .def("fromHex", &CTextU::fromHexNumber<int>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
+        .def("fromHex", &CTextU::fromHexNumber<long long>, "create a hexadecimal string from the number", py::arg("i"), py::arg("hasBase") = false, py::arg("upper") = false, py::arg("append") = false)
         .def("fromInteger", &CTextU::fromInteger<char>, "convert the decimal nteger to string", py::arg("i"), py::arg("append") = false, py::arg("padd") = 0, py::arg("paddValue") = '0')
         .def("fromInteger", &CTextU::fromInteger<int>, "convert the decimal nteger to string", py::arg("i"), py::arg("append") = false, py::arg("padd") = 0, py::arg("paddValue") = '0')
         .def("fromInteger", &CTextU::fromInteger<long long>, "convert the decimal integer to string", py::arg("i"), py::arg("append") = false, py::arg("padd") = 0, py::arg("paddValue") = '0')
@@ -357,7 +360,7 @@ PYBIND11_MODULE(ctextlib, m)
         .def("sort", &CTextU::sort)
         .def("split", [](CTextU& s, const wchar_t* sep = CTextU::Separators)->vector<wstring> { vector<wstring> res;  s.split(res, false, sep); return res; }, "fills the STL container with the collected substrings", py::arg("sep") = CTextU::Separators)
         .def("str", (const wchar_t* (CTextU::*)(size_t pos) const) &CTextU::str, "return text buffer", py::arg("pos") = 0)
-        .def("toBinaryNumber", &CTextU::toBinaryNumber, "if the string contains a binary number, convert it  ")
+        .def("toBinary", &CTextU::toBinary, "if the string contains a binary number, convert it  ")
         .def("toHexNumber", &CTextU::toHexNumber, "if the string contains a hex number, convert it , 1E --> 30")
         .def("toDouble", &CTextU::toDouble)
         .def("toInteger", &CTextU::toInteger)
